import defu from "defu";
import DefaultSanityClient from "../../client/DefaultSanityClient.js";
import MinimalSanityClient from "../../client/MinimalSanityClient.js";
import { useRuntimeConfig } from "#imports";
const clients = {};
export default function useSanityClient(type, config) {
  const sanityConfig = config || defu(useRuntimeConfig().sanity, useRuntimeConfig().public.sanity || {});
  const visualEditingEnabled = type !== "minimal" && sanityConfig.visualEditing && sanityConfig.visualEditing.previewMode !== false;
  const clientType = (type || (sanityConfig.minimalClient ? "minimal" : "default")) + (visualEditingEnabled ? "-visual-editing" : "");
  if (clientType in clients) return clients[clientType];
  const clientConfig = visualEditingEnabled ? {
    ...sanityConfig,
    token: sanityConfig.visualEditing?.token,
    useCdn: false
  } : sanityConfig;
  const client = new (clientType === "minimal" ? MinimalSanityClient : DefaultSanityClient)(clientConfig);
  if (visualEditingEnabled) client.createQueryStore();
  clients[clientType] = client;
  return client;
}
